@@ -8,10 +8,10 @@ import marshmallow
 
 from unimatrix.ext import webapi
 from unimatrix.ext.webapi import PublicResourceEndpointSet
-from unimatrix.ext.webapi import __boot__
+from unimatrix.ext.webapi import __unimatrix__ as boot
 
 
-asyncio.run(__boot__.on_setup())
+asyncio.run(boot.on_setup())
 
 
 app = webapi.Application(
