@@ -6,6 +6,7 @@ from .exceptions import UpstreamConnectionFailure
 from .keytrustpolicy import KeyTrustPolicy
 from .resourceendpointset import ResourceEndpointSet
 from .resourceendpointset import PublicResourceEndpointSet
+from .service import Service
 
 
 __all__ = [
@@ -13,6 +14,7 @@ __all__ = [
     'Application',
     'EndpointSet',
     'PublicEndpointSet',
+    'Service',
     'UpstreamConnectionFailure',
     'UpstreamServiceNotAvailable',
 ]
