@@ -1,10 +1,9 @@
+# pylint: disable=line-too-long
 """Declares :class:`Application`."""
 import asyncio
 import logging
 import os
 import random
-import urllib.parse
-
 
 import fastapi
 import unimatrix.runtime
@@ -20,15 +19,13 @@ from unimatrix.ext import jose
 from unimatrix.ext.model.exc import CanonicalException
 from unimatrix.ext.model.exc import FeatureNotSupported
 
+from .exceptions import TryAgain
 from .exceptions import UpstreamServiceNotAvailable
 from .exceptions import UpstreamConnectionFailure
 from .healthcheck import live as liveness_handler
 from .healthcheck import ready as readyness_handler
 from .metadata import APIMetadataService
 from .models import APIMetadata
-from .models import Identification
-from .models import IDToken
-from .trustedidentityproviders import TrustedIdentityProviders
 
 
 class Application(fastapi.FastAPI):
@@ -51,8 +48,10 @@ class Application(fastapi.FastAPI):
         # the Unimatrix Framework.
         exception_handlers = kwargs.setdefault('exception_handlers', {})
         exception_handlers.update({
+            asyncio.TimeoutError: self.canonical_exception,
             CanonicalException: self.canonical_exception,
             ConnectionError: self.canonical_exception,
+            TimeoutError: self.canonical_exception,
             UnsatisfiedDependency: self.canonical_exception
         })
 
@@ -61,16 +60,10 @@ class Application(fastapi.FastAPI):
         allowed_hosts = kwargs.pop('allowed_hosts', None)
         self.audience = kwargs.pop('audience', None)
         self.issuer = kwargs.pop('issuer', None)
-        self.openid = kwargs.pop('openid', TrustedIdentityProviders())
 
         # Check if debug endpoints are enabled
         enable_debug_endpoints = kwargs.pop('enable_debug_endpoints', False)
 
-        # Add the trusted OpenID identity providers.
-        openid_providers = kwargs.pop('openid_providers')
-        for url, params in dict.items(openid_providers): # pragma: no cover
-            self.add_openid_provider(url, **params)
-
         super().__init__(*args, **kwargs)
 
         # Add standard health-check routes. The initial use case here was
@@ -106,12 +99,21 @@ class Application(fastapi.FastAPI):
         @self.on_event('startup')
         async def on_startup(): # pylint: disable=unused-variable
             await unimatrix.runtime.on('boot') # pragma: no cover
-            await self.openid.on_setup() # pragma: no cover
+            self.logger.info("Unimatrix bootstrap complete")
 
         @self.on_event('shutdown')
         async def on_shutdown(): # pylint: disable=unused-variable
             await unimatrix.runtime.on('shutdown') # pragma: no cover
 
+        @self.middleware('http')
+        async def set_cache_headers(request: Request, call_next):
+            response = await call_next(request)
+            if not response.headers.get('Cache-Control'):
+                response.headers['Cache-Control'] = "no-cache, no-store, must-revalidate"
+                response.headers['Pragma'] = "no-cache"
+                response.headers['Expires'] = "0"
+            return response
+
         # Add mandatory middleware to the application.
         self.add_middleware(
             TrustedHostMiddleware,
@@ -154,30 +156,6 @@ class Application(fastapi.FastAPI):
             svc = APIMetadataService()
             return APIMetadata(**await svc.get(self, request))
 
-        # Add the .well-known/identify endpoint.
-        @self.post('/.well-known/identify', tags=['OAuth 2.0'])
-        async def identify(request: Request, dto: Identification):
-            """Identify the request using an OpenID-compliant identity
-            token. Issue an access token that is trusted by the other
-            endpoints of this API.
-
-            The identity must at least contain the following OpenID
-            standard claims:
-
-            - `iss`
-            - `aud`
-            - `sub`
-
-            If any of the claims is missing or invalid, or the ID token is
-            malformed, then the endpoint responds with a `422` status code.
-            """
-            claims = await self.openid.verify(dto.id_token)
-            token = IDToken(**claims)
-            return await token.sign(
-                aud=self.get_audience(request),
-                iss=self.get_issuer(request)
-            )
-
     async def canonical_exception(self, request, exception):
         """Handles a canonical exception to a standard error message format."""
         if isinstance(exception, ConnectionRefusedError):
@@ -199,6 +177,11 @@ class Application(fastapi.FastAPI):
             return await self.canonical_exception(
                 request, FeatureNotSupported()
             )
+        elif isinstance(exception, (asyncio.TimeoutError, TimeoutError)):
+            #count = int(request.headers.get('X-Retry') or 0)
+            return await self.canonical_exception(
+                request, TryAgain(30)
+            )
         elif isinstance(exception, CanonicalException):
             if exception.http_status_code >= 500:
                 exception.log(self.logger.exception)
@@ -228,21 +211,6 @@ class Application(fastapi.FastAPI):
             max_age=max_age or self.cors_max_age
         )
 
-    def add_openid_provider(self,
-        url: str,
-        audience: str,
-        issuer: str = None,
-        tags: list = None
-    ): # pragma: no cover
-        """Add a trusted OpenID identity provider."""
-        p = urllib.parse.urlparse(url)
-        if issuer is None:
-            issuer = f'{p.scheme}://{p.netloc}'
-        if not tags:
-            tags = []
-        tags.insert(0, 'openid')
-        self.openid.add(url, audience, issuer, tags)
-
     def get_audience(self, request: Request) -> str:
         """Return the issuer used for JWS access tokens."""
         return self.audience or f'{request.url.scheme}://{request.url.netloc}'
