@@ -52,3 +52,32 @@ class TrustIssues(CanonicalException):
         "Verify that the credential (i.e. bearer token or X.509 certificate) "
         "was issued by an authority that is trusted by this system."
     )
+
+
+class UntrustedIssuer(TrustIssues):
+    code = 'UNTRUSTED_ISSUER'
+
+    def __init__(self, issuer, accepted):
+        super().__init__(
+            message=(
+                "The credential was issued by an entity not trusted by this "
+                "system."
+            ),
+            detail=(
+                f"The credential was issued by {issuer}, but the system only "
+                f"accepts these issuers: {str.join(', ', accepted)}"
+            )
+        )
+
+
+class TryAgain(CanonicalException):
+    http_status_code = 503
+    message = "The service is currently not available."
+    detail = (
+        "Network or other infrastructure issues prevent "
+        "proper operation of the service."
+    )
+    hint = "Try again in 600 seconds."
+
+    def __init__(self, retry_after): # pragma: no cover
+        super().__init__()
