@@ -14,6 +14,7 @@ from fastapi import Request
 from fastapi.security import HTTPBearer
 from fastapi.security import HTTPAuthorizationCredentials
 from pydantic import BaseModel
+from unimatrix.conf import settings
 
 from .auth import IHTTPAuthenticationService
 from .exceptions import BearerAuthenticationRequired
@@ -395,7 +396,8 @@ class ResourceEndpointSet(metaclass=ResourceEndpointSetMetaclass):
         the ``aud`` claim of bearer tokens. The default implementation returns
         an empty list.
         """
-        return self.accepted_audiences
+        return self.accepted_audiences\
+            + [f"https://{self.request.url.netloc}", "self"]
 
     def get_scope(self) -> set:
         """Return the scope that is required for authenticated requests."""
@@ -405,13 +407,16 @@ class ResourceEndpointSet(metaclass=ResourceEndpointSetMetaclass):
         """Return the list of trusted issuers as compared against the ``iss``
         claim.
         """
-        return self.trusted_issuers
+        return list(self.trusted_issuers)\
+            + list(settings.OAUTH2_TRUSTED_STS)\
+            + [f"https://{self.request.url.netloc}", "self"]
 
     async def dispatch(self, *args, **kwargs) -> dict:
         """Dispatch the incoming HTTP request to the appropriate request
         handler.
         """
-        await self.authenticate(kwargs.pop('_bearer', None))
+        if self.require_authentication:
+            await self.authenticate(kwargs.pop('_bearer', None))
         handler = getattr(self, self.action)
 
         assert callable(handler), handler #nosec
@@ -431,12 +436,12 @@ class ResourceEndpointSet(metaclass=ResourceEndpointSetMetaclass):
         could resolve a principal and subject, raise an exception if the
         resource requires authentication.
         """
-        if not self.trust_policy\
-        and self.require_authentication\
-        and not self.trust_local:
-            raise TrustIssues
         self.principal = None
         if dto is not None:
+            if not self.trust_policy\
+            and self.require_authentication\
+            and not self.trust_local:
+                raise TrustIssues
             self.principal = await authentication.resolve(
                 str.encode(dto.credentials),
                 audience=self.get_audience(),
