@@ -1,5 +1,6 @@
 # pylint: skip-file
 import asyncio
+import time
 import unittest
 
 from fastapi.testclient import TestClient
@@ -34,6 +35,13 @@ class BearerAuthorizationTestCase(unittest.TestCase):
         self.view_class.add_to_router(self.app, '/test')
 
     def get_token(self, claims: dict = None):
+        now = int(time.time())
+        claims = claims or {}
+        claims.setdefault('iss', 'self')
+        claims.setdefault('aud', 'self')
+        claims.setdefault('sub', 'self')
+        claims.setdefault('iat', now)
+        claims.setdefault('exp', now+60)
         response = self.client.post('/debug/token', json=claims or {})
         return response.text
 
